<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output method="html" version="4.1" encoding="UTF-8" indent="yes"/>

	<xsl:variable name="Total">
		<Salespersons>
			<xsl:for-each select="Team/Salesperson">
				<xsl:variable name="SubTotal">			
					<xsl:for-each select="Client/Training/Price">
							<EuroPrice>
								<xsl:call-template name="PriceInEuro">
									<xsl:with-param name="unit" select="@unit"/>
									<xsl:with-param name="amount" select="."/>											
								</xsl:call-template>
							</EuroPrice>						
					</xsl:for-each>
				</xsl:variable>
				<Salesperson firstName="{@firstName}" 	lastName="{@lastName}" total="{ sum( $SubTotal/EuroPrice/.)}" />
		</xsl:for-each>
		</Salespersons>
	</xsl:variable>				

	<xsl:template match="/" >
		<html>
			<head>
				<title></title>
			</head>
			<body>
				<h1>Valtech's SalesPersons</h1>
				<xsl:apply-templates select="Team/Salesperson"/>
			</body>
		</html>
	</xsl:template>
	
	<xsl:template match="Salesperson" >
		<h2>
		<!-- nécessité d'utiliser une variable locale -->
			<xsl:variable name="total" select=" $Total/Salespersons/Salesperson[ @firstName = current()/@firstName and @lastName = current()/@lastName ]/@total " />
			<xsl:if test=" not ( $total &lt;
$Total/Salespersons/Salesperson/@total )
">
				<xsl:attribute name="style">color:blue</xsl:attribute>
			</xsl:if>
			
			<xsl:value-of select="@firstName"/> 	<xsl:value-of select="@lastName"/>
		</h2>
		<table border="1">
			<tbody>
				<tr>
					<th>Client</th><th>Price in Euro</th><th>Original Price</th>
				</tr>
				<xsl:apply-templates />
			</tbody>
		</table>
		<br/>
		<h3>
		<!-- marche avec XSLT , saxon , pas XML Spy -->
		Total : <xsl:value-of select="sum( $Total/Salespersons/Salesperson[@firstName = current()/@firstName and @lastName = current()/@lastName ]/@total )"/> Euros
		</h3>
		<br/>
	</xsl:template>

	<xsl:template match="Training">
		<tr>
			<td><xsl:value-of select="../@name"/></td>
			<td>
				<xsl:call-template name="PriceInEuro">
					<xsl:with-param name="unit" select="Price/@unit"/>
					<xsl:with-param name="amount" select="Price/."/>							
				</xsl:call-template>
			</td>
			<td><xsl:value-of select="format-number( Price/. , '000.00') "/><xsl:text>  </xsl:text><xsl:value-of select="Price/@unit"/></td>
		</tr>
	</xsl:template>
	
	<xsl:template name="PriceInEuro">
		<xsl:param name="unit"/>
		<xsl:param name="amount" />
		<xsl:choose>
			<xsl:when test=" $unit='Euro' "><xsl:value-of select=" format-number( . , '000.00') "/></xsl:when>
			<xsl:when test=" $unit='French Franc' "><xsl:value-of select=" format-number( $amount div 6.56, '000.00') "/></xsl:when>
		</xsl:choose>
	</xsl:template>	
	
</xsl:stylesheet>
