<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output method="text" encoding="UTF-8" />

	<xsl:template name="threedigits">
		<xsl:param name="number"/>
		<xsl:value-of select="format-number( $number, '000' )"/>
	</xsl:template>
	
	<xsl:template name="fiftychars">
		<xsl:param name="s"/>
		<xsl:value-of select="substring(concat('                                                  ',$s), string-length( $s) +1 	)"/>
	</xsl:template>

	<xsl:template match="/" >
		<xsl:document href="Stations.txt" >
			<xsl:text>ID*Name&#xa;</xsl:text>
			<xsl:apply-templates select="//Station" />
		</xsl:document>

		<xsl:document href="Lines.txt" >
			<xsl:text>ID*Name*NbStations&#xa;</xsl:text>
			<xsl:apply-templates select="//Line" />
		</xsl:document>
		
		<xsl:document href="Positionning.txt" >
			<xsl:text>StationID*LineID*IndexInLine&#xa;</xsl:text>
			<xsl:apply-templates select="//Station" mode="index"/>
		</xsl:document>		
	</xsl:template>
	
	<xsl:template match="Station">
		<xsl:call-template name="threedigits">
			<xsl:with-param name="number">
				<xsl:number/>
			</xsl:with-param>
		</xsl:call-template>		
		<xsl:text>*</xsl:text>
		<xsl:call-template name="fiftychars" >
			<xsl:with-param name="s" select="@name" />
		</xsl:call-template>		
		<xsl:text>&#xa;</xsl:text>		
	</xsl:template>

	<xsl:template match="Station" mode="index">
		<xsl:variable name="stationnumber" select="position()" />
		<xsl:variable name="stationid" select="@id" />

		<xsl:for-each select="//StationRef[@ref=$stationid]" >
			<xsl:call-template name="threedigits">
				<xsl:with-param name="number" select="$stationnumber" />
			</xsl:call-template>			
			<xsl:text>*</xsl:text>		
			<xsl:call-template name="threedigits">
				<xsl:with-param name="number" select="count(parent::*/preceding-sibling::*)+1" />
			</xsl:call-template>
			<xsl:text>*</xsl:text>		
			<xsl:call-template name="threedigits">
				<xsl:with-param name="number" select="position()" />
			</xsl:call-template>
			<xsl:text>&#xa;</xsl:text>		
		</xsl:for-each>			
	</xsl:template>

		
	<xsl:template match="Line">
		<xsl:call-template name="threedigits">
			<xsl:with-param name="number">
				<xsl:number/>
			</xsl:with-param>
		</xsl:call-template>		
		<xsl:text>*</xsl:text>
		<xsl:call-template name="fiftychars" >
			<xsl:with-param name="s" select="@name"/>
		</xsl:call-template>				
		<xsl:text>*</xsl:text>
		<xsl:call-template name="threedigits">
			<xsl:with-param name="number" select="count(StationRef)" />
		</xsl:call-template>				
		<xsl:text>&#xa;</xsl:text>		
	</xsl:template>
	
</xsl:stylesheet>
